"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[2323],{41598(e,p,a){a.d(p,{createEventModelingServices:()=>t.g});var t=a(83461);a(50211)}}]);