"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[9571],{92574(e,t,n){n.d(t,{dockerFile:()=>x});var r=n(47228),a="from",o=RegExp("^(\\s*)\\b("+a+")\\b","i"),s=["run","cmd","entrypoint","shell"],l=RegExp("^(\\s*)("+s.join("|")+")(\\s+\\[)","i"),i="expose",g=RegExp("^(\\s*)("+i+")(\\s+)","i"),u="("+[a,i].concat(s).concat(["arg","from","maintainer","label","env","add","copy","volume","user","workdir","onbuild","stopsignal","healthcheck","shell"]).join("|")+")",d=RegExp("^(\\s*)"+u+"(\\s*)(#.*)?$","i"),p=RegExp("^(\\s*)"+u+"(\\s+)","i");let x=(0,r.I)({start:[{regex:/^\s*#.*$/,sol:!0,token:"comment"},{regex:o,token:[null,"keyword"],sol:!0,next:"from"},{regex:d,token:[null,"keyword",null,"error"],sol:!0},{regex:l,token:[null,"keyword",null],sol:!0,next:"array"},{regex:g,token:[null,"keyword",null],sol:!0,next:"expose"},{regex:p,token:[null,"keyword",null],sol:!0,next:"arguments"},{regex:/./,token:null}],from:[{regex:/\s*$/,token:null,next:"start"},{regex:/(\s*)(#.*)$/,token:[null,"error"],next:"start"},{regex:/(\s*\S+\s+)(as)/i,token:[null,"keyword"],next:"start"},{token:null,next:"start"}],single:[{regex:/(?:[^\\']|\\.)/,token:"string"},{regex:/'/,token:"string",pop:!0}],double:[{regex:/(?:[^\\"]|\\.)/,token:"string"},{regex:/"/,token:"string",pop:!0}],array:[{regex:/\]/,token:null,next:"start"},{regex:/"(?:[^\\"]|\\.)*"?/,token:"string"}],expose:[{regex:/\d+$/,token:"number",next:"start"},{regex:/[^\d]+$/,token:null,next:"start"},{regex:/\d+/,token:"number"},{regex:/[^\d]+/,token:null},{token:null,next:"start"}],arguments:[{regex:/^\s*#.*$/,sol:!0,token:"comment"},{regex:/"(?:[^\\"]|\\.)*"?$/,token:"string",next:"start"},{regex:/"/,token:"string",push:"double"},{regex:/'(?:[^\\']|\\.)*'?$/,token:"string",next:"start"},{regex:/'/,token:"string",push:"single"},{regex:/[^#"']+[\\`]$/,token:null},{regex:/[^#"']+$/,token:null,next:"start"},{regex:/[^#"']+/,token:null},{token:null,next:"start"}],languageData:{commentTokens:{line:"#"}}})},47228(e,t,n){function r(e){a(e,"start");var t,n,r,s={},l=e.languageData||{},i=!1;for(var g in e)if(g!=l&&e.hasOwnProperty(g))for(var u=s[g]=[],d=e[g],p=0;p<d.length;p++){var x=d[p];u.push(new o(x,e)),(x.indent||x.dedent)&&(i=!0)}return{name:l.name,startState:function(){return{state:"start",pending:null,indent:i?[]:null}},copyState:function(e){var t={state:e.state,pending:e.pending,indent:e.indent&&e.indent.slice(0)};return e.stack&&(t.stack=e.stack.slice(0)),t},token:(t=s,function(e,n){if(n.pending){var r=n.pending.shift();return 0==n.pending.length&&(n.pending=null),e.pos+=r.text.length,r.token}for(var a=t[n.state],o=0;o<a.length;o++){var s=a[o],l=(!s.data.sol||e.sol())&&e.match(s.regex);if(l){s.data.next?n.state=s.data.next:s.data.push?((n.stack||(n.stack=[])).push(n.state),n.state=s.data.push):s.data.pop&&n.stack&&n.stack.length&&(n.state=n.stack.pop()),s.data.indent&&n.indent.push(e.indentation()+e.indentUnit),s.data.dedent&&n.indent.pop();var i=s.token;if(i&&i.apply&&(i=i(l)),l.length>2&&s.token&&"string"!=typeof s.token){n.pending=[];for(var g=2;g<l.length;g++)l[g]&&n.pending.push({text:l[g],token:s.token[g-1]});return e.backUp(l[0].length-(l[1]?l[1].length:0)),i[0]}if(i&&i.join)return i[0];return i}}return e.next(),null}),indent:(n=s,r=l,function(e,t){if(null==e.indent||r.dontIndentStates&&r.dontIndentStates.indexOf(e.state)>-1)return null;var a=e.indent.length-1,o=n[e.state];e:for(;;){for(var s=0;s<o.length;s++){var l=o[s];if(l.data.dedent&&!1!==l.data.dedentIfLineStart){var i=l.regex.exec(t);if(i&&i[0]){a--,(l.next||l.push)&&(o=n[l.next||l.push]),t=t.slice(i[0].length);continue e}}}break}return a<0?0:e.indent[a]}),mergeTokens:l.mergeTokens,languageData:l}}function a(e,t){if(!e.hasOwnProperty(t))throw Error("Undefined state "+t+" in simple mode")}function o(e,t){(e.next||e.push)&&a(t,e.next||e.push),this.regex=function(e){if(!e)return/(?:)/;var t="";return e instanceof RegExp?(e.ignoreCase&&(t="i"),e.unicode&&(t+="u"),e=e.source):e=String(e),RegExp("^(?:"+e+")",t)}(e.regex),this.token=function(e){if(!e)return null;if(e.apply)return e;if("string"==typeof e)return e.replace(/\./g," ");for(var t=[],n=0;n<e.length;n++)t.push(e[n]&&e[n].replace(/\./g," "));return t}(e.token),this.data=e}n.d(t,{I:()=>r})}}]);
//# sourceMappingURL=9571.70584c7b7e2ccab5.js.map?v=70584c7b7e2ccab5