"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[8680],{43419(a,p,e){e.d(p,{createPacketServices:()=>t.$});var t=e(27561);e(50211)}}]);