"use strict";(self.rspackChunk_jupyterlab_application_top=self.rspackChunk_jupyterlab_application_top||[]).push([[6740],{24735(t,e,n){function r(){return{mangle:!1,walkTokens(t){if("link"!==t.type||!t.href.startsWith("mailto:"))return;let e=t.href.substring(7),n=function(t){let e="",n,r,a=t.length;for(n=0;n<a;n++)r=t.charCodeAt(n),Math.random()>.5&&(r="x"+r.toString(16)),e+="&#"+r+";";return e}(e);t.href=`mailto:${n}`,1===t.tokens.length&&"text"===t.tokens[0].type&&t.tokens[0].text===e&&(t.text=n,t.tokens[0].text=n)}}}n.r(e),n.d(e,{mangle:()=>r})}}]);
//# sourceMappingURL=6740.4ed9b0f07867ecc0.js.map?v=4ed9b0f07867ecc0